@@ -119,8 +119,7 @@ def test_suite():
     suite = unittest.TestSuite()
     if BS_INSTALLED:
         suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(SoupParserTestCase)])
-        if sys.version_info[0] < 3:
-            suite.addTests([make_doctest('../../../../doc/elementsoup.txt')])
+        #suite.addTests([make_doctest('../../../../doc/elementsoup.txt')])  # FIXME: Py2-only ?
     return suite
 
 
