@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-
 """
 Web IO test cases (wsgiref)
 """
 
-from __future__ import with_statement, absolute_import
 
 import unittest
 import textwrap
@@ -18,7 +15,8 @@ from .dummy_http_server import webserver, HTTPRequestCollector
 class HttpIOTestCase(HelperTestCase):
     etree = etree
 
-    def _parse_from_http(self, data, code=200, headers=None, parser=None):
+    def _parse_from_http(self, data, code=200, headers=None):
+        parser = self.etree.XMLParser(no_network=False)
         handler = HTTPRequestCollector(data, code, headers)
         with webserver(handler) as host_url:
             tree = self.etree.parse(host_url + 'TEST', parser=parser)
@@ -26,14 +24,14 @@ class HttpIOTestCase(HelperTestCase):
         return tree
 
     def test_http_client(self):
-        tree = self._parse_from_http(_bytes('<root><a/></root>'))
+        tree = self._parse_from_http(b'<root><a/></root>')
         self.assertEqual('root', tree.getroot().tag)
         self.assertEqual('a', tree.getroot()[0].tag)
 
     def test_http_client_404(self):
         try:
-            self._parse_from_http(_bytes('<root/>'), code=404)
-        except IOError:
+            self._parse_from_http(b'<root/>', code=404)
+        except OSError:
             self.assertTrue(True)
         else:
             self.assertTrue(False, "expected IOError")
@@ -41,7 +39,7 @@ class HttpIOTestCase(HelperTestCase):
     def test_http_client_gzip(self):
         f = BytesIO()
         gz = gzip.GzipFile(fileobj=f, mode='w', filename='test.xml')
-        gz.write(_bytes('<root><a/></root>'))
+        gz.write(b'<root><a/></root>')
         gz.close()
         data = f.getvalue()
         del f, gz
@@ -52,18 +50,19 @@ class HttpIOTestCase(HelperTestCase):
         self.assertEqual('a', tree.getroot()[0].tag)
 
     def test_parser_input_mix(self):
-        data = _bytes('<root><a/></root>')
+        data = b'<root><a/></root>'
         handler = HTTPRequestCollector(data)
+        parser = self.etree.XMLParser(no_network=False)
 
         with webserver(handler) as host_url:
-            tree = self.etree.parse(host_url)
+            tree = self.etree.parse(host_url, parser=parser)
             root = tree.getroot()
             self.assertEqual('a', root[0].tag)
 
             root = self.etree.fromstring(data)
             self.assertEqual('a', root[0].tag)
 
-            tree = self.etree.parse(host_url)
+            tree = self.etree.parse(host_url, parser=parser)
             root = tree.getroot()
             self.assertEqual('a', root[0].tag)
 
@@ -110,14 +109,17 @@ class HttpIOTestCase(HelperTestCase):
                         load_dtd=True, no_network=True))
             except self.etree.XMLSyntaxError:
                 self.assertTrue("myentity" in str(sys.exc_info()[1]))
+                self.assertEqual(1, len(responses))  # DTD not read
+            except OSError:
+                self.assertTrue("failed to load" in str(sys.exc_info()[1]))
+                self.assertEqual(2, len(responses))  # nothing read
             else:
                 self.assertTrue(False)
-            self.assertEqual(1, len(responses))  # DTD not read
 
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTests([unittest.makeSuite(HttpIOTestCase)])
+    suite.addTests([unittest.defaultTestLoader.loadTestsFromTestCase(HttpIOTestCase)])
     return suite
 
 
