@@ -1,21 +1,20 @@
-# -*- coding: utf-8 -*-
-
 """
 Tests for the incremental XML serialisation API.
 """
 
-from __future__ import absolute_import
-
 import io
 import os
 import sys
 import unittest
 import textwrap
 import tempfile
+from io import BytesIO
+
+from unittest import skipIf
 
 from lxml.etree import LxmlSyntaxError
 
-from .common_imports import etree, BytesIO, HelperTestCase, skipIf, _str
+from .common_imports import etree, HelperTestCase
 
 
 class _XmlFileTestCaseBase(HelperTestCase):
@@ -357,7 +356,7 @@ class TempPathXmlFileTestCase(_XmlFileTestCaseBase):
 
 
 class SimpleFileLikeXmlFileTestCase(_XmlFileTestCaseBase):
-    class SimpleFileLike(object):
+    class SimpleFileLike:
         def __init__(self, target):
             self._target = target
             self.write = target.write
@@ -402,7 +401,7 @@ class SimpleFileLikeXmlFileTestCase(_XmlFileTestCaseBase):
         class WriteError(Exception):
             pass
 
-        class Writer(object):
+        class Writer:
             def __init__(self, trigger):
                 self._trigger = trigger
                 self._failed = False
@@ -530,7 +529,7 @@ class HtmlFileTestCase(_XmlFileTestCaseBase):
 
     def test_attribute_quoting_unicode(self):
         with etree.htmlfile(self._file) as xf:
-            with xf.element("tagname", attrib={"attr": _str('"misquöted\\u3344\\U00013344"')}):
+            with xf.element("tagname", attrib={"attr": '"misquöted\u3344\U00013344"'}):
                 xf.write("foo")
 
         self.assertXml('<tagname attr="&quot;misqu&#xF6;ted&#x3344;&#x13344;&quot;">foo</tagname>')
@@ -597,7 +596,6 @@ class AsyncXmlFileTestCase(HelperTestCase):
             except StopIteration as ex:
                 return ex.value
 
-    @skipIf(sys.version_info < (3, 5), "requires support for async-def (Py3.5+)")
     def test_async(self):
         code = textwrap.dedent("""\
         async def test_async_xmlfile(close=True, buffered=True):
@@ -660,12 +658,12 @@ class AsyncXmlFileTestCase(HelperTestCase):
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTests([
-        unittest.makeSuite(BytesIOXmlFileTestCase),
-        unittest.makeSuite(TempXmlFileTestCase),
-        unittest.makeSuite(TempPathXmlFileTestCase),
-        unittest.makeSuite(SimpleFileLikeXmlFileTestCase),
-        unittest.makeSuite(HtmlFileTestCase),
-        unittest.makeSuite(AsyncXmlFileTestCase),
+        unittest.defaultTestLoader.loadTestsFromTestCase(BytesIOXmlFileTestCase),
+        unittest.defaultTestLoader.loadTestsFromTestCase(TempXmlFileTestCase),
+        unittest.defaultTestLoader.loadTestsFromTestCase(TempPathXmlFileTestCase),
+        unittest.defaultTestLoader.loadTestsFromTestCase(SimpleFileLikeXmlFileTestCase),
+        unittest.defaultTestLoader.loadTestsFromTestCase(HtmlFileTestCase),
+        unittest.defaultTestLoader.loadTestsFromTestCase(AsyncXmlFileTestCase),
     ])
     return suite
 
